@@ -19,12 +19,12 @@ public:
     ~KBlocksDummyAI();
 
 public:
-    void startGame(SingleGameInterface *p);
-    void stopGame();
+    void startGame(SingleGameInterface *p) override;
+    void stopGame() override;
 
-    void pauseGame(bool flag);
+    void pauseGame(bool flag) override;
 
-    void think(GamePlayer_ActionList *actionList);
+    void think(GamePlayer_ActionList *actionList) override;
 
 protected:
     bool mPauseFlag;
