@@ -15,7 +15,6 @@ using namespace std;
 
 #include <QAction>
 #include <KActionCollection>
-#include <KMainWindow>
 #include <KXmlGuiWindow>
 #include <klocalizedstring.h>
 
@@ -26,18 +25,18 @@ class KBlocksKeyboardPlayer : public QObject, public GamePlayerInterface
     Q_OBJECT
 
 public:
-    explicit KBlocksKeyboardPlayer(KXmlGuiWindow *parent, string name = "", bool netMode = false);
+    explicit KBlocksKeyboardPlayer(KXmlGuiWindow *parent, const string &name = "", bool netMode = false);
     ~KBlocksKeyboardPlayer();
 
 public:
-    void startGame(SingleGameInterface *p);
-    void stopGame();
+    void startGame(SingleGameInterface *p) override;
+    void stopGame() override;
 
-    void pauseGame(bool flag);
+    void pauseGame(bool flag) override;
 
-    void think(GamePlayer_ActionList *actionList);
+    void think(GamePlayer_ActionList *actionList) override;
 
-    string getName();
+    string getName() override;
 
 private:
     void bindKeys();
@@ -55,23 +54,23 @@ private slots:
     void rotateCCW();
 
 protected:
-    SingleGameInterface *mpGame;
+    SingleGameInterface *mpGame = nullptr;
     bool mPauseFlag;
 
-    QAction *rotatecw;
-    QAction *rotateccw;
-    QAction *moveleft;
-    QAction *moveright;
-    QAction *movedown;
-    QAction *pushdown;
+    QAction *rotatecw = nullptr;
+    QAction *rotateccw = nullptr;
+    QAction *moveleft = nullptr;
+    QAction *moveright = nullptr;
+    QAction *movedown = nullptr;
+    QAction *pushdown = nullptr;
 
 private:
     bool mNetMode;
     string mPlayerName;
     GamePlayer_ActionList mActionList;
 
-    KXmlGuiWindow *mpKeyWindow;
-    KActionCollection *mpKeyShortcuts;
+    KXmlGuiWindow *mpKeyWindow = nullptr;
+    KActionCollection *mpKeyShortcuts = nullptr;
 };
 
 #endif
