@@ -13,7 +13,6 @@
 #include <QObject>
 #include <QUdpSocket>
 #include <QString>
-#include <QByteArray>
 
 class KBlocksNetClient : public QObject
 {
@@ -37,7 +36,7 @@ private slots:
     void receivedData();
 
 private:
-    QUdpSocket *mpClientSocket;
+    QUdpSocket *mpClientSocket = nullptr;
 
     QHostAddress mLocalAddress;
     quint16 mLocalPort;
