@@ -9,8 +9,6 @@
 ***************************************************************************/
 #include "KBlocksRepWin.h"
 
-#include <KLocalizedString>
-#include <QStatusBar>
 #include <QPixmapCache>
 
 #include <qdatetime.h>
@@ -151,7 +149,7 @@ void KBlocksRepWin::snapshotView()
 {
     if (!mSnapshotFilename.isEmpty()) {
         //mSnapshoter = QPixmap::grabWindow(mpGameView->winId());
-        mSnapshoter = QPixmap::grabWidget(this);
+        mSnapshoter = grab();
         QString tmpFilename = mSnapshotFolder + mSnapshotFilename + QStringLiteral("_")
                               + getTimeString() + QStringLiteral(".png");
         mSnapshoter.save(tmpFilename);
