@@ -16,7 +16,6 @@
 #include <QString>
 
 #include <KGamePopupItem>
-#include <KgDifficulty>
 
 #include "KBlocksSound.h"
 #include "KBlocksGraphics.h"
@@ -80,19 +79,19 @@ public slots:
     void playDropSound();
 
 protected:
-    void drawBackground(QPainter *painter, const QRectF &rect);
+    void drawBackground(QPainter *painter, const QRectF &rect) override;
 
 private:
-    GameLogicInterface *mpGameLogic;
+    GameLogicInterface *mpGameLogic = nullptr;
     bool mGameStarted;
 
-    KBlocksGraphics *mpGrafx;
-    KBlocksSound *mpSnd;
+    KBlocksGraphics *mpGrafx = nullptr;
+    KBlocksSound *mpSnd = nullptr;
 
     int mSceneGamesPerLine;
     bool mGameAnimEnabled;
     bool mWaitForAllUpdate;
-    bool *maGameReadySignal;
+    bool *maGameReadySignal = nullptr;
 
     bool mSnapshotMode;
 
@@ -100,10 +99,10 @@ private:
 
     int mMaxCapacity;
     int mGroupCount;
-    KBlocksItemGroup **maGroupList;
-    KBlocksScore **maGameScoreList;
+    KBlocksItemGroup **maGroupList = nullptr;
+    KBlocksScore **maGameScoreList = nullptr;
 
-    KGamePopupItem *mMessageBox;
+    KGamePopupItem *mMessageBox = nullptr;
 
     int mUpdateInterval;
     QTimer mUpdateTimer;
